<?php
/**
 * Custom template tags for this theme
 *
 * @package Volcano
 * @since volcano 1.0.0
 */

if ( ! function_exists( 'volcano_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @return void
	 */
	function volcano_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )
		);
		echo '<span class="posted-on">';
		printf(
			/* translators: %s: Publish date. */
			'<i class="ti-time"></i> %s',
			$time_string // phpcs:ignore WordPress.Security.EscapeOutput
		);
		echo '</span>';
	}
}

if ( ! function_exists( 'volcano_posted_by' ) ) {
	/**
	 * Prints HTML with meta information about theme author.
	 *
	 * @return void
	 */
	function volcano_posted_by() {
		if ( ! get_the_author_meta( 'description' ) && post_type_supports( get_post_type(), 'author' ) ) {
			echo '<span class="byline">';
			printf(
				/* translators: %s: Author name. */
				esc_html__( 'By %s', 'volcano' ),
				'<a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" rel="author">' . esc_html( get_the_author() ) . '</a>'
			);
			echo '</span>';
		}
	}
}

if ( ! function_exists( 'volcano_post_taxonomies' ) ) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 * Footer entry meta is displayed differently in archives and single posts.
	 *
	 * @return void
	 */
	function volcano_post_taxonomies() {

		// Early exit if not a post.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		if ( has_category() || has_tag() ) {

				echo '<div class="post-taxonomies">';

				/* translators: Used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( __( ', ', 'volcano' ) );
			if ( $categories_list ) {
				printf(
					/* translators: %s: List of categories. */
					'<span class="cat-links">' . esc_html__( 'Categorized as %s', 'volcano' ) . ' </span>',
					$categories_list // phpcs:ignore WordPress.Security.EscapeOutput
				);
			}

				/* translators: Used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '', __( ', ', 'volcano' ) );
			if ( $tags_list ) {
				printf(
					/* translators: %s: List of tags. */
					'<span class="tags-links">' . esc_html__( 'Tagged %s', 'volcano' ) . '</span>',
					$tags_list // phpcs:ignore WordPress.Security.EscapeOutput
				);
			}
				echo '</div>';
		}
	}
}

if ( ! function_exists( 'volcano_entry_meta' ) ) {
	/**
	 * Prints HTML with meta information
	 *
	 * @return void
	 */
	function volcano_entry_meta() {

		// Early exit if not a post.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		echo '<div class="entry-meta">';
		// Posted by.
		volcano_posted_by();
		// Posted on.
		volcano_posted_on();
		echo '</div>';
	}
}

if ( ! function_exists( 'volcano_read_more' ) ) {
	/**
	 * Creates continue reading link for excerpt.
	 */
	function volcano_read_more() {
		if ( ! is_admin() ) {
			printf(
				'<a class="volcano-read-more volcano-btn volcano-btn-fill" href="%s">%s<i class="ti-angle-double-right" aria-hidden="true"></i></a>',
				esc_url(get_permalink()),
				esc_html('Continue')
			);
			return '<a class="volcano-read-more volcano-btn volcano-btn-fill" href="' . esc_url(get_permalink()) . '">' . esc_html('Continue reading') . '</a>';
		}
	}
}

if ( ! function_exists( 'volcano_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 *
	 * @return void
	 */
	function volcano_post_thumbnail() {
		if ( ! volcano_can_show_post_thumbnail() ) {
			return;
		}
		?>

		<?php if ( is_singular() ) : ?>

			<figure class="post-thumbnail">
				<?php
				// Lazy-loading attributes should be skipped for thumbnails since they are immediately in the viewport.
				the_post_thumbnail( 'post-thumbnail', array( 'loading' => false ) );
				?>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
					<figcaption class="wp-caption-text"><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
			</figure><!-- .post-thumbnail -->

		<?php else : ?>

			<figure class="post-thumbnail">
				<a class="post-thumbnail-inner" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
					<?php the_post_thumbnail( 'post-thumbnail' ); ?>
				</a>
				<?php if ( wp_get_attachment_caption( get_post_thumbnail_id() ) ) : ?>
					<figcaption class="wp-caption-text"><?php echo wp_kses_post( wp_get_attachment_caption( get_post_thumbnail_id() ) ); ?></figcaption>
				<?php endif; ?>
			</figure>

		<?php endif; ?>
		<?php
	}
}

if ( ! function_exists( 'volcano_the_posts_navigation' ) ) {
	/**
	 * Print the next and previous posts navigation.
	 *
	 * @return void
	 */
	function volcano_the_posts_navigation() {
		the_posts_pagination(
			array(
				'mid_size'  => 2,
				'class'     => 'volcano-pagination',
				'prev_text' => sprintf(
					'<i class="%s" aria-hidden="true"></i>',
					is_rtl() ? 'ti-arrow-right' : 'ti-arrow-left'
				),
				'next_text' => sprintf(
					'<i class="%s" aria-hidden="true"></i>',
					is_rtl() ? 'ti-arrow-left' : 'ti-arrow-right'
				),
			)
		);
	}
}
